/*
 * Copyright 2017 Esri.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

package com.example.app;

import com.esri.arcgisruntime.ArcGISRuntimeEnvironment;
import javafx.application.Application;
import javafx.scene.Scene;
import javafx.scene.layout.StackPane;
import javafx.stage.Stage;

import com.esri.arcgisruntime.layers.ArcGISMapImageLayer;
import com.esri.arcgisruntime.mapping.ArcGISMap;
import com.esri.arcgisruntime.mapping.BasemapStyle;
import com.esri.arcgisruntime.mapping.Viewpoint;
import com.esri.arcgisruntime.mapping.view.MapView;
import com.esri.arcgisruntime.security.AuthenticationManager;
import com.esri.arcgisruntime.security.DefaultAuthenticationChallengeHandler;
import com.esri.arcgisruntime.security.OAuthConfiguration;

public class App extends Application {

  private MapView mapView;

  @Override
  public void start(Stage stage) {

    try {

      // set title, size, and add scene to stage
      stage.setTitle("Access services with OAuth 2.0");

      stage.setWidth(800);
      stage.setHeight(700);
      stage.show();

      // create stack pane and application scene
      StackPane stackPane = new StackPane();
      Scene scene = new Scene(stackPane);
      stage.setScene(scene);

      // Note: it is not best practice to store API keys in source code.
      // The API key is referenced here for the convenience of this tutorial.
      String yourApiKey = "YOUR_API_KEY";
      ArcGISRuntimeEnvironment.setApiKey(yourApiKey);

      // create a map view and it to the stack pane
      mapView = new MapView();
      stackPane.getChildren().add(mapView);

      ArcGISMap map = new ArcGISMap(BasemapStyle.ARCGIS_TOPOGRAPHIC);

      // set the map on the map view
      mapView.setMap(map);

      mapView.setViewpoint(new Viewpoint(34.02700, -118.80543, 72000.0 ));

      // set up an oauth config with url to portal, a client id and a re-direct url
      OAuthConfiguration oAuthConfiguration = new OAuthConfiguration("YOUR_ORGANIZATION_URL", "YOUR_CLIENT_ID", "YOUR_REDIRECT_URL");

      // set up the authentication manager to handle authentication challenges
      DefaultAuthenticationChallengeHandler defaultAuthenticationChallengeHandler = new DefaultAuthenticationChallengeHandler();
      AuthenticationManager.setAuthenticationChallengeHandler(defaultAuthenticationChallengeHandler);
      // add the OAuth configuration
      AuthenticationManager.addOAuthConfiguration(oAuthConfiguration);

      ArcGISMapImageLayer trafficLayer = new ArcGISMapImageLayer("https://traffic.arcgis.com/arcgis/rest/services/World/Traffic/MapServer");
      map.getOperationalLayers().add(trafficLayer);

    } catch (Exception e) {
      // on any error, display the stack trace.
      e.printStackTrace();
    }
  }

  /**
   * Stops and releases all resources used in application.
   */
  @Override
  public void stop() {

    if (mapView != null) {
      mapView.dispose();
    }
  }

  /**
   * Opens and runs application.
   *
   * @param args arguments passed to this application
   */
  public static void main(String[] args) {

    Application.launch(args);
  }
}

